@@ -52,7 +52,7 @@ GLMModel <- function(family = NULL, ...) {
       newdata <- as.data.frame(newdata)
       predict(object, newdata = newdata, type = "response")
     },
-    varimp = function(object, ...) varimp_pchisq(object)
+    varimp = function(object, ...) varimp_wald(object)
   )
   
 }
