@@ -52,7 +52,7 @@ SurvRegModel <- function(dist = c("weibull", "exponential", "gaussian",
         Hmisc::Mean(object)(predict(object, newdata = newdata, type = "lp"))
       }
     },
-    varimp = function(object, ...) varimp_pchisq(object)
+    varimp = function(object, ...) varimp_wald(object)
   )
   
 }
